# nessaid_readline
Basic readline interface for CLI apps, common for Windows, Linux and Mac systems

## Installation

This package can be installed by cloning this repo and running python3 setup.py install from top directory. It's also available in pypi. pip3 install nessaid_readline will install the package.

## Usage:
TODO:
